mathtools.interval_string_to_pair_and_indicators
================================================

.. autofunction:: abjad.tools.mathtools.interval_string_to_pair_and_indicators.interval_string_to_pair_and_indicators
   :noindex:
